"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var IqCalendarComponent = (function () {
    function IqCalendarComponent() {
        this.dateSelected = new core_1.EventEmitter();
        this.timeMask = [/[0-2]/, /[0-9]/, ':', /[0-5]/, /[0-9]/];
        this.timeInput = new forms_1.FormControl();
    }
    IqCalendarComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.date = this.selectedDate ? new Date(this.selectedDate.getTime()) : new Date();
        this.updateViewDays();
        this.emitDateOnTimeSelected();
        setTimeout(function () {
            if (_this.selectedDate) {
                var hours = _this.selectedDate.getHours() < 10 ? _this.selectedDate.getHours() + '0' : String(_this.selectedDate.getHours());
                var minutes = _this.selectedDate.getMinutes() < 10 ? _this.selectedDate.getMinutes() + '0' : String(_this.selectedDate.getMinutes());
                _this.timeInput.setValue(hours + ':' + minutes, { emitEvent: false });
            }
        }, 1);
    };
    IqCalendarComponent.prototype.emitDateOnTimeSelected = function () {
        var _this = this;
        this.timeInput
            .valueChanges
            .subscribe(function (newValue) {
            var values = newValue.split(':');
            if (!isNaN(values[0]) && !isNaN(values[1]) && _this.selectedDate) {
                _this.selectedDate.setHours(values[0]);
                _this.selectedDate.setMinutes(values[1]);
                _this.dateSelected.emit(_this.selectedDate);
            }
        });
    };
    IqCalendarComponent.prototype.prevMonth = function () {
        var currentMonth = this.date.getMonth();
        if (currentMonth === 0) {
            this.date.setMonth(11);
            this.prevYear();
        }
        else {
            this.date.setMonth(currentMonth - 1);
        }
        this.updateViewDays();
    };
    IqCalendarComponent.prototype.nextMonth = function () {
        var currentMonth = this.date.getMonth();
        if (currentMonth === 11) {
            this.date.setMonth(0);
            this.nextYear();
        }
        else {
            this.date.setMonth(currentMonth + 1);
        }
        this.updateViewDays();
    };
    IqCalendarComponent.prototype.prevYear = function () {
        this.date.setFullYear(this.date.getFullYear() - 1);
        this.updateViewDays();
    };
    IqCalendarComponent.prototype.nextYear = function () {
        this.date.setFullYear(this.date.getFullYear() + 1);
        this.updateViewDays();
    };
    IqCalendarComponent.prototype.updateViewDays = function () {
        this.weeks = [];
        var firstDayDate = new Date(this.date.getFullYear(), this.date.getMonth(), 1);
        var offset = firstDayDate.getDay();
        this.populatePreviousMonthDates(offset);
        var dayNumber = this.populateCurrentMonthDates(offset);
        this.populateNextMonthDates(dayNumber);
    };
    IqCalendarComponent.prototype.populateNextMonthDates = function (dayNumber) {
        if (dayNumber < 6) {
            for (var i = ++dayNumber; i <= 6; i++) {
                this.weeks[this.weeks.length - 1][i] = {
                    currentMonth: false,
                    currentDate: false,
                    prevMonth: false,
                    nextMonth: true,
                    isSelectedDate: this.isSelectedDate(this.getNextMonth(), i - dayNumber + 1),
                    value: i - dayNumber + 1
                };
            }
        }
    };
    IqCalendarComponent.prototype.getPreviousMonth = function () {
        return this.date.getMonth() === 0 ? 11 : this.date.getMonth() - 1;
    };
    IqCalendarComponent.prototype.getNextMonth = function () {
        return this.date.getMonth() === 11 ? 0 : this.date.getMonth() + 1;
    };
    IqCalendarComponent.prototype.populateCurrentMonthDates = function (offset) {
        var lastDayDate = new Date(this.date.getFullYear(), this.date.getMonth() + 1, 0);
        var numberOfDaysInMonth = lastDayDate.getDate();
        var dayNumber;
        for (var i = 0; i < numberOfDaysInMonth; i++) {
            var week = Math.floor((i + offset) / 7);
            dayNumber = (i + offset) % 7;
            if (!this.weeks[week]) {
                this.weeks.push([]);
            }
            this.weeks[week][dayNumber] = {
                currentMonth: true,
                currentDate: this.isCurrentDate(i + 1),
                prevMonth: false,
                nextMonth: false,
                isSelectedDate: this.isSelectedDate(this.date.getMonth(), i + 1),
                value: i + 1
            };
        }
        return dayNumber;
    };
    IqCalendarComponent.prototype.isCurrentDate = function (dayNumber) {
        var today = new Date();
        return this.date.getFullYear() === today.getFullYear()
            && this.date.getMonth() === today.getMonth()
            && dayNumber === today.getDate();
    };
    IqCalendarComponent.prototype.populatePreviousMonthDates = function (offset) {
        if (offset > 0) {
            this.weeks.push([]);
            for (var i = 0; i <= offset; i++) {
                var lastDayPreviousMonth = new Date(this.date.getFullYear(), this.date.getMonth(), 0);
                this.weeks[0][offset - i] = {
                    currentMonth: false,
                    currentDate: false,
                    prevMonth: true,
                    nextMonth: false,
                    isSelectedDate: this.isSelectedDate(this.getPreviousMonth(), lastDayPreviousMonth.getDate() - i + 1),
                    value: lastDayPreviousMonth.getDate() - i + 1
                };
            }
        }
    };
    IqCalendarComponent.prototype.selectMonth = function (month) {
        var lastDay = new Date(this.date.getFullYear(), this.date.getMonth() + 1, 0);
        if (this.date.getDate() === lastDay.getDate()) {
            this.date.setDate(1);
            this.date.setMonth(month);
            lastDay = new Date(this.date.getFullYear(), this.date.getMonth() + 1, 0);
            this.date.setDate(lastDay.getDate());
        }
        this.date.setMonth(month);
        this.updateViewDays();
    };
    IqCalendarComponent.prototype.setYear = function (year) {
        if (!isNaN(year) && year >= 1970 && year <= 9999) {
            this.date.setFullYear(year);
            this.updateViewDays();
        }
        else {
            this.date.setFullYear(new Date().getFullYear());
        }
    };
    IqCalendarComponent.prototype.setHours = function (hours) {
        var hoursStr;
        var minutesInput = this.timeInput.value;
        var minutesStr = minutesInput ? minutesInput.substring(3, 5) : '00';
        if (hours && hours >= 0 && hours <= 23) {
            this.date.setHours(hours);
            hoursStr = hours < 10 ? '0' + hours : String(hours);
        }
        else {
            hoursStr = '00';
        }
        this.timeInput.setValue(hoursStr + ':' + minutesStr, { emitEvent: false });
    };
    IqCalendarComponent.prototype.setMinutes = function (minutes) {
        var hoursInput = this.timeInput.value;
        var hoursStr = hoursInput ? hoursInput.substring(0, 2) : '00';
        var minutesStr;
        if (minutes && minutes >= 0 && minutes <= 59) {
            this.date.setMinutes(minutes);
            minutesStr = minutes < 10 ? '0' + minutes : String(minutes);
        }
        else {
            minutesStr = '00';
        }
        this.timeInput.setValue(hoursStr + ':' + minutesStr, { emitEvent: false });
    };
    IqCalendarComponent.prototype.onDateSelected = function (date, prevMonth, nextMonth) {
        this.date.setDate(date);
        if (prevMonth) {
            this.prevMonth();
        }
        if (nextMonth) {
            this.nextMonth();
        }
        this.selectedDate = this.date;
        this.dateSelected.emit(this.date);
        this.updateViewDays();
    };
    IqCalendarComponent.prototype.isSelectedDate = function (month, date) {
        if (!this.selectedDate) {
            return false;
        }
        else {
            return this.selectedDate.getFullYear() === this.date.getFullYear()
                && this.selectedDate.getMonth() === month
                && this.selectedDate.getDate() === date;
        }
    };
    IqCalendarComponent.prototype.onKeyDown = function (event) {
        if (event.keyCode === 13) {
            this.setYear(event.target.value);
            event.stopPropagation();
        }
    };
    return IqCalendarComponent;
}());
IqCalendarComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'iq-calendar',
                template: '<div class="calendar-container" [class.horizontal]="options.horizontal" [class.lg]="options.size === \'lg\'" [class.sm]="options.size === \'sm\'"><div class="row date-selector-row"><div class="col-sm-6"><div class="input-group"><span class="input-group-btn"><button tabindex="-1" type="button" class="btn btn-left btn-chevron btn-sm btn-default" (click)="prevMonth()"><i class="glyphicon glyphicon-chevron-left"></i></button></span><select tabindex="-1" class="form-control input-sm" (change)="selectMonth($event.target.value)"><option *ngFor="let month of translations.monthNames" [value]="translations.monthNames.indexOf(month)" [selected]="month === translations.monthNames[date.getMonth()]">{{month}}</option></select><span class="input-group-btn"><button tabindex="-1" type="button" class="btn btn-right btn-chevron btn-sm btn-default" (click)="nextMonth()"><i class="glyphicon glyphicon-chevron-right"></i></button></span></div></div><div class="col-sm-2"></div><div class="col-sm-4"><div class="input-group"><span class="input-group-btn"><button tabindex="-1" type="button" class="btn btn-left btn-chevron btn-sm btn-default" (click)="prevYear()"><i class="glyphicon glyphicon-chevron-left"></i></button> </span><input tabindex="-1" class="form-control input-sm text-center" type="text" [value]="date.getFullYear()" (keydown)="onKeyDown($event)" (blur)="setYear($event.target.value)"> <span class="input-group-btn"><button tabindex="-1" type="button" class="btn btn-right btn-chevron btn-sm btn-default" (click)="nextYear()"><i class="glyphicon glyphicon-chevron-right"></i></button></span></div></div></div><div class="row"><div class="col-sm-12"><div class="iq-calendar"><table class="table"><thead><th class="text-center">{{translations.daysAbrev[0]}}</th><th class="text-center">{{translations.daysAbrev[1]}}</th><th class="text-center">{{translations.daysAbrev[2]}}</th><th class="text-center">{{translations.daysAbrev[3]}}</th><th class="text-center">{{translations.daysAbrev[4]}}</th><th class="text-center">{{translations.daysAbrev[5]}}</th><th class="text-center">{{translations.daysAbrev[6]}}</th></thead><tbody><tr *ngFor="let week of weeks"><td *ngFor="let day of week" class="text-center" [class.selected-date]="day && day.isSelectedDate" [class.current-month]="day && day.currentMonth" [class.current-date]="day && day.currentDate"><a *ngIf="day" class="date-value" (click)="onDateSelected(day.value, day.prevMonth, day.nextMonth)">{{day.value}}</a></td></tr></tbody></table></div></div></div><div class="row date-selector-row" *ngIf="options?.time"><div class="col-sm-4 col-sm-offset-4"><input class="form-control input-sm text-center" [textMask]="{mask: timeMask}" placeholder="hh:mm" [formControl]="timeInput"></div></div></div>',
                styles: ['.calendar-container {    background: #ddd;    border: 1px solid #ddd;    border-radius: 3px;    margin-top: 10px;    position: absolute;    padding: 1px;    right: 0;    width: 280px;    z-index: 1040;}.calendar-container input,.calendar-container select {    border-left: 0;    border-right: 0;    box-shadow: none;    padding: 2px;}.calendar-container.horizontal {    margin-right: 15px;}.iq-calendar {    background: #fff;    border-radius: 2px;    padding: 5px;    margin-top: 5px;}.iq-calendar table {    margin-top: 10px;    margin-bottom: 0;}.iq-calendar table tr td {    border-top: none;    padding: 0;}.iq-calendar table tr td a {    padding: 6px;    min-width: 24px;    display: inline-block;}.date-value {    color: #aaa;}.current-date {    position: relative;}.current-date a.date-value {    border: 1px solid #cee5f3;    border-radius: 3px;}.current-date a.date-value::before {    content: "";    display: inline-block;    border: solid transparent;    border-width: 0 0 10px 10px;    border-bottom-color: #337ab7;    border-top-color: rgba(0,0,0,.2);    position: absolute;    bottom: 1px;    right: 6px;}.iq-calendar table tr td a.date-value:hover {    background: #666;    border-radius: 3px;    color: #fff;    cursor: pointer;    text-decoration: none;}.current-month .date-value {    color: #000;}.input-group-btn > .btn.btn-chevron {    color: #666;    padding: 5px 2px}.calendar-container::before {    border-left: 7px solid transparent;    border-right: 7px solid transparent;    border-bottom: 7px solid #441010;    border-bottom-color: rgba(0,0,0,.2);    top: -8px;    right: 14px;    content: "";    position: absolute;}.calendar-container.sm::before {    right: 10px;}.calendar-container.sm::after {    right: 11px;}.calendar-container.lg::before {    right: 19px;}.calendar-container.lg::after {    right: 20px;}.calendar-container::after {    border-left: 6px solid transparent;    border-right: 6px solid transparent;    border-bottom: 6px solid #fff;    top: -7px;    right: 15px;    content: "";    position: absolute;}.date-selector-row {    padding: 3px 1px 0px;}.btn-left {    border-right: none;}.btn-right {    border-left: none;}.selected-date a {    background: #d1edff;    border-radius: 3px;    color: #fff;}']
            },] },
];
/** @nocollapse */
IqCalendarComponent.ctorParameters = function () { return []; };
IqCalendarComponent.propDecorators = {
    'options': [{ type: core_1.Input },],
    'translations': [{ type: core_1.Input },],
    'date': [{ type: core_1.Input },],
    'selectedDate': [{ type: core_1.Input },],
    'dateSelected': [{ type: core_1.Output },],
};
exports.IqCalendarComponent = IqCalendarComponent;
//# sourceMappingURL=iq-calendar.component.js.map