"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var iq_datepicker_english_translation_1 = require("./iq-datepicker-english-translation");
var forms_1 = require("@angular/forms");
var iq_calendar_component_1 = require("../iq-calendar/iq-calendar.component");
require("rxjs/add/operator/debounceTime");
require("rxjs/add/operator/distinctUntilChanged");
var KEY_CODE_ENTER = 13;
var KEY_CODE_TAB = 9;
var VALUE_ACCESSOR = {
    provide: forms_1.NG_VALUE_ACCESSOR,
    useExisting: core_1.forwardRef(function () { return IqDatepickerComponent; }),
    multi: true
};
var IqDatepickerComponent = (function () {
    function IqDatepickerComponent(elementRef) {
        this.elementRef = elementRef;
        this.options = {};
        this.translations = new iq_datepicker_english_translation_1.IqDatepickerEnglishTranslation();
        this.dateSelected = new core_1.EventEmitter();
        this.selectedDateInput = new forms_1.FormControl();
        this.calendarVisible = false;
        this.disabled = false;
        this.timeMask = [/[0-2]/, /[0-9]/, ':', /[0-5]/, /[0-9]/];
        this.dateMask = [];
        this.yearMask = [/[1-3]/, /\d/, /\d/, /\d/];
        this.monthMask = [/[0-1]/, /\d/];
        this.dayMask = [/[0-3]/, /\d/];
        this.defaults = {
            size: 'md',
            calendarBtnClass: 'btn btn-default',
            calendarBtnIcon: 'glyphicon glyphicon-calendar',
            removeBtnClass: 'btn btn-default',
            removeBtnVisible: true,
            removeBtnIcon: 'glyphicon glyphicon-remove',
            horizontal: false,
            dateFormat: 'dd/MM/yyyy',
            showPlaceholder: true,
            time: false,
            minimalMode: false,
            inputCss: ''
        };
        this.propagateChange = function (_) {
        };
    }
    IqDatepickerComponent.prototype.writeValue = function (obj) {
        var date = obj;
        if (typeof obj === 'string' || typeof obj === 'number') {
            date = new Date(date);
        }
        this.onDateSelected(date);
    };
    IqDatepickerComponent.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    IqDatepickerComponent.prototype.registerOnTouched = function (fn) {
    };
    IqDatepickerComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
        this.selectedDateInput.disable(isDisabled);
    };
    IqDatepickerComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.setDefaults();
        this.buildDateMask();
        this.selectedDateInput
            .valueChanges
            .debounceTime(100)
            .distinctUntilChanged()
            .subscribe(function (newValue) {
            if (newValue) {
                var year = newValue.substring(_this.yearIndex, _this.yearIndex + 4);
                var month = newValue.substring(_this.monthIndex, _this.monthIndex + 2);
                var day = newValue.substring(_this.dayIndex, _this.dayIndex + 2);
                var hoursStr = newValue.substring(11, 13);
                var minutesStr = newValue.substring(14, 16);
                var hours = hoursStr.length > 0 && !isNaN(hoursStr) ? Number(hoursStr) : null;
                var minutes = minutesStr.length > 0 && !isNaN(minutesStr) ? Number(minutesStr) : null;
                if (_this.calendarComponent) {
                    if (!isNaN(month)) {
                        _this.calendarComponent.selectMonth(month - 1);
                    }
                    if (!isNaN(year)) {
                        _this.calendarComponent.setYear(year);
                    }
                    _this.calendarComponent.setHours(isNaN(hours) ? 0 : hours);
                    _this.calendarComponent.setMinutes(isNaN(minutes) ? 0 : minutes);
                }
                if (!isNaN(year) && !isNaN(month) && !isNaN(day)) {
                    if (!_this.options.time) {
                        _this.onDateSelected(new Date(year, month - 1, day));
                    }
                    else {
                        if (hours && minutes) {
                            _this.onDateSelected(new Date(year, month - 1, day, hours, minutes));
                        }
                    }
                }
            }
            else {
                _this.onDateSelected(null);
            }
        });
        this.yearIndex = this.options.dateFormat.indexOf('yyyy');
        this.monthIndex = this.options.dateFormat.indexOf('MM');
        this.dayIndex = this.options.dateFormat.indexOf('dd');
    };
    IqDatepickerComponent.prototype.setDefaults = function () {
        var _this = this;
        Object
            .keys(this.defaults)
            .filter(function (key) { return _this.options[key] === undefined || _this.options[key] === null; })
            .forEach(function (key) { return _this.options[key] = _this.defaults[key]; });
    };
    IqDatepickerComponent.prototype.onDateSelected = function (date) {
        this.selectedDateInput.patchValue(this.dateToString(date), { emitEvent: false });
        this.selectedDate = date ? new Date(date.getTime()) : null;
        this.propagateChange(this.selectedDate);
        this.dateSelected.emit(this.selectedDate);
    };
    IqDatepickerComponent.prototype.dateToString = function (date) {
        if (date) {
            var dateStr = this.getDateFormat();
            var month = date.getMonth() + 1;
            var day = date.getDate();
            var hours = date.getHours();
            var minutes = date.getMinutes();
            dateStr = dateStr
                .replace(/dd/g, day < 10 ? '0' + day : String(day))
                .replace(/MM/g, month < 10 ? '0' + month : String(month))
                .replace(/yyyy/g, String(date.getFullYear()))
                .replace(/hh/g, hours < 10 ? '0' + hours : String(hours))
                .replace(/mm/g, minutes < 10 ? '0' + minutes : String(minutes));
            return dateStr;
        }
        else {
            return null;
        }
    };
    IqDatepickerComponent.prototype.clear = function () {
        this.onDateSelected(null);
        if (this.calendarComponent) {
            this.calendarComponent.selectedDate = null;
            this.calendarComponent.updateViewDays();
        }
    };
    IqDatepickerComponent.prototype.showCalendar = function () {
        this.calendarVisible = true;
    };
    IqDatepickerComponent.prototype.hideCalendar = function () {
        this.calendarVisible = false;
    };
    IqDatepickerComponent.prototype.toggleCalendar = function () {
        this.calendarVisible = !this.calendarVisible;
    };
    IqDatepickerComponent.prototype.handleKeyDown = function (event) {
        if (event.keyCode === KEY_CODE_ENTER || event.keyCode === KEY_CODE_TAB) {
            this.completeValuesAndHide(event);
        }
    };
    IqDatepickerComponent.prototype.completeValuesAndHide = function (event) {
        var textInput = this.selectedDateInput.value;
        if (textInput) {
            var year = textInput.substring(this.yearIndex, this.yearIndex + 4);
            var month = textInput.substring(this.monthIndex, this.monthIndex + 2);
            var day = textInput.substring(this.dayIndex, this.dayIndex + 2);
            var hours = textInput.substring(11, 13);
            var minutes = textInput.substring(14, 16);
            var date = void 0;
            if (!isNaN(year) && !isNaN(month) && !isNaN(day)) {
                date = new Date(year, month - 1, day);
            }
            date.setHours(isNaN(hours) ? 0 : hours);
            date.setMinutes(isNaN(minutes) ? 0 : minutes);
            this.onDateSelected(date);
        }
        else if (event.keyCode === KEY_CODE_ENTER) {
            this.onDateSelected(new Date());
        }
        this.hideCalendar();
    };
    IqDatepickerComponent.prototype.handleClick = function (event) {
        if (this.calendarVisible && !this.elementRef.nativeElement.contains(event.target)) {
            this.completeValuesAndHide(event);
        }
    };
    IqDatepickerComponent.prototype.buildDateMask = function () {
        var _this = this;
        var items = [];
        items[this.options.dateFormat.indexOf('dd')] = this.dayMask;
        items[this.options.dateFormat.indexOf('MM')] = this.monthMask;
        items[this.options.dateFormat.indexOf('yyyy')] = this.yearMask;
        Object.keys(items).forEach(function (key, i) {
            if (i > 0) {
                _this.dateMask.push('/');
            }
            items[key].forEach(function (item) { return _this.dateMask.push(item); });
        });
        if (this.options.time) {
            this.dateMask.push(' ');
            (_a = this.dateMask).push.apply(_a, this.timeMask);
        }
        var _a;
    };
    IqDatepickerComponent.prototype.getMask = function () {
        return this.dateMask;
    };
    IqDatepickerComponent.prototype.getDateFormat = function () {
        return this.options.dateFormat + (this.options.time ? ' hh:mm' : '');
    };
    IqDatepickerComponent.prototype.getPlaceholder = function () {
        return this.options.showPlaceholder ? this.getDateFormat() : '';
    };
    return IqDatepickerComponent;
}());
IqDatepickerComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'iq-datepicker',
                template: '<div class="datepicker" [class.input-group]="!options.minimalMode"><input [class]="\'form-control\' + \' \' + options.inputCss" [class.input-lg]="options.size === \'lg\'" [class.input-sm]="options.size === \'sm\'" [formControl]="selectedDateInput" (focus)="showCalendar()" [textMask]="{mask: getMask()}" [placeholder]="getPlaceholder()" type="text"> <span class="minimalMode" *ngIf="options.minimalMode"><button tabindex="-1" [class]="options.removeBtnClass" [class.btn-lg]="options.size === \'lg\'" [class.btn-sm]="options.size === \'sm\'" (click)="clear()" *ngIf="options.removeBtnVisible" [disabled]="disabled" type="button"><i class="glyphicon glyphicon-remove"></i></button> </span><span class="input-group-btn" *ngIf="!options.minimalMode"><button tabindex="-1" [class]="options.removeBtnClass" [class.btn-lg]="options.size === \'lg\'" [class.btn-sm]="options.size === \'sm\'" (click)="clear()" *ngIf="options.removeBtnVisible" [disabled]="disabled" type="button"><i class="glyphicon glyphicon-remove"></i></button> <button tabindex="-1" [class]="options.calendarBtnClass" [class.btn-lg]="options.size === \'lg\'" [class.btn-sm]="options.size === \'sm\'" (click)="toggleCalendar()" [disabled]="disabled" type="button"><i class="glyphicon glyphicon-calendar"></i></button></span></div><iq-calendar *ngIf="calendarVisible" [translations]="translations" [options]="options" [selectedDate]="selectedDate" (dateSelected)="onDateSelected($event)"></iq-calendar>',
                styles: ['.datepicker {    position: relative;}.datepicker .minimalMode {    display: none;}.datepicker:hover .minimalMode {    display: block;}.datepicker .minimalMode button {    background: transparent;    border: none;    position: absolute;    top: 2px;    right: 0;}.datepicker .minimalMode button:focus,.datepicker .minimalMode button:active {    box-shadow: none;    outline: none;}'],
                providers: [VALUE_ACCESSOR]
            },] },
];
/** @nocollapse */
IqDatepickerComponent.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
]; };
IqDatepickerComponent.propDecorators = {
    'options': [{ type: core_1.Input },],
    'translations': [{ type: core_1.Input },],
    'dateSelected': [{ type: core_1.Output },],
    'calendarComponent': [{ type: core_1.ViewChild, args: [iq_calendar_component_1.IqCalendarComponent,] },],
    'handleKeyDown': [{ type: core_1.HostListener, args: ['keydown', ['$event'],] },],
    'handleClick': [{ type: core_1.HostListener, args: ['document:click', ['$event'],] },],
};
exports.IqDatepickerComponent = IqDatepickerComponent;
//# sourceMappingURL=iq-datepicker.component.js.map